==> react-codemirror-merge-4.21.2.tgz: package/esm/Internal.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["className", "children", "orientation", "revertControls", "highlightChanges", "gutter", "collapseUnchanged", "renderRevertControl"],
  _excluded2 = ["modified", "modifiedExtension", "original", "originalExtension", "theme", "dispatch"];
import React, { useEffect, useImperativeHandle, useRef } from 'react';
import { getDefaultExtensions } from '@uiw/react-codemirror';
import { MergeView } from '@codemirror/merge';
import { useStore } from './store';
import { jsx as _jsx } from "react/jsx-runtime";
export var Internal = /*#__PURE__*/React.forwardRef((props, ref) => {
  var {
      className,
      children,
      orientation,
      revertControls,
      highlightChanges,
      gutter,
      collapseUnchanged,
      renderRevertControl
    } = props,
    elmProps = _objectWithoutPropertiesLoose(props, _excluded);
  var _useStore = useStore(),
    {
      modified,
      modifiedExtension,
      original,
      originalExtension,
      theme,
      dispatch
    } = _useStore,
    otherStore = _objectWithoutPropertiesLoose(_useStore, _excluded2);
  var editor = useRef(null);
  var view = useRef();
  var opts = {
    orientation,
    revertControls,
    highlightChanges,
    gutter,
    collapseUnchanged,
    renderRevertControl
  };
  useImperativeHandle(ref, () => ({
    container: editor.current,
    view: view.current,
    modified,
    original,
    config: _extends({
      a: original,
      b: modified,
      parent: editor.current
    }, opts)
  }), [editor, view, modified, original, opts]);
  useEffect(() => {
    if (!view.current && editor.current) {
      view.current = new MergeView(_extends({
        a: _extends({}, original, {
          extensions: [...((originalExtension == null ? void 0 : originalExtension.extension) || []), ...getDefaultExtensions(_extends({}, originalExtension == null ? void 0 : originalExtension.option, {
            theme
          }))]
        }),
        b: _extends({}, modified, {
          extensions: [...((modifiedExtension == null ? void 0 : modifiedExtension.extension) || []), ...getDefaultExtensions(_extends({}, modifiedExtension == null ? void 0 : modifiedExtension.option, {
            theme
          }))]
        }),
        parent: editor.current
      }, opts));
    }
  }, [view, editor]);
  useEffect(() => {
    var _view$current5;
    if (original && original.doc && view.current) {
      var _view$current;
      var originalDoc = (_view$current = view.current) == null ? void 0 : _view$current.a.state.doc.toString();
      if (originalDoc !== original.doc) {
        var _view$current2;
        (_view$current2 = view.current) == null ? void 0 : _view$current2.a.dispatch({
          changes: {
            from: 0,
            to: originalDoc.length,
            insert: original.doc || ''
          }
          // effects: StateEffect.reconfigure.of([
          //   ...(originalExtension?.extension || []),
          //   ...getDefaultExtensions({ ...originalExtension?.option, theme }),
          // ])
        });
      }
    }

    if (modified && modified.doc && view.current) {
      var _view$current3;
      var modifiedDoc = (_view$current3 = view.current) == null ? void 0 : _view$current3.b.state.doc.toString();
      if (modifiedDoc !== modified.doc) {
        var _view$current4;
        (_view$current4 = view.current) == null ? void 0 : _view$current4.b.dispatch({
          changes: {
            from: 0,
            to: modifiedDoc.length,
            insert: modified.doc || ''
          }
          // effects: StateEffect.reconfigure.of([
          //   ...(modifiedExtension?.extension || []),
          //   ...getDefaultExtensions({ ...modifiedExtension?.option, theme }),
          // ])
        });
      }
    }

    (_view$current5 = view.current) == null ? void 0 : _view$current5.destroy();
    view.current = new MergeView(_extends({
      a: _extends({}, original, {
        extensions: [...((originalExtension == null ? void 0 : originalExtension.extension) || []), ...getDefaultExtensions(_extends({}, originalExtension == null ? void 0 : originalExtension.option, {
          theme
        }))]
      }),
      b: _extends({}, modified, {
        extensions: [...((modifiedExtension == null ? void 0 : modifiedExtension.extension) || []), ...getDefaultExtensions(_extends({}, modifiedExtension == null ? void 0 : modifiedExtension.option, {
          theme
        }))]
      }),
      parent: editor.current
    }, opts));
  }, [view, theme, editor.current, original, modified, originalExtension, modifiedExtension]);
  useEffect(() => () => view.current && view.current.destroy(), []);
  useEffect(() => {
    if (view.current) {
      var _opts = {};
      if (otherStore.orientation !== orientation) {
        _opts.orientation = orientation;
      }
      if (otherStore.revertControls !== revertControls) {
        _opts.revertControls = revertControls;
      }
      if (otherStore.highlightChanges !== highlightChanges) {
        _opts.highlightChanges = highlightChanges;
      }
      if (otherStore.gutter !== gutter) {
        _opts.gutter = gutter;
      }
      if (otherStore.collapseUnchanged !== collapseUnchanged) {
        _opts.collapseUnchanged = collapseUnchanged;
      }
      if (otherStore.renderRevertControl !== renderRevertControl) {
        _opts.collapseUnchanged = collapseUnchanged;
      }
      if (Object.keys(_opts).length && dispatch && view.current) {
        view.current.reconfigure(_extends({}, _opts));
        dispatch(_extends({}, _opts));
      }
    }
  }, [dispatch, view, orientation, revertControls, highlightChanges, gutter, collapseUnchanged, renderRevertControl]);
  var defaultClassNames = 'cm-merge-theme';
  return /*#__PURE__*/_jsx("div", _extends({
    ref: editor,
    className: "" + defaultClassNames + (className ? " " + className : '')
  }, elmProps, {
    children: children
  }));
});
Internal.displayName = 'CodeMirrorMerge.Internal';

==> react-codemirror-merge-4.21.11.tgz: package/esm/Internal.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["className", "children", "orientation", "revertControls", "highlightChanges", "gutter", "collapseUnchanged", "renderRevertControl"],
  _excluded2 = ["modified", "modifiedExtension", "original", "originalExtension", "theme", "dispatch"];
import React, { useEffect, useImperativeHandle, useRef } from 'react';
import { getDefaultExtensions } from '@uiw/react-codemirror';
import { MergeView } from '@codemirror/merge';
import { useStore } from './store';
import { jsx as _jsx } from "react/jsx-runtime";
export var Internal = /*#__PURE__*/React.forwardRef((props, ref) => {
  var {
      className,
      children,
      orientation,
      revertControls,
      highlightChanges,
      gutter,
      collapseUnchanged,
      renderRevertControl
    } = props,
    elmProps = _objectWithoutPropertiesLoose(props, _excluded);
  var _useStore = useStore(),
    {
      modified,
      modifiedExtension,
      original,
      originalExtension,
      theme,
      dispatch
    } = _useStore,
    otherStore = _objectWithoutPropertiesLoose(_useStore, _excluded2);
  var editor = useRef(null);
  var view = useRef();
  var opts = {
    orientation,
    revertControls,
    highlightChanges,
    gutter,
    collapseUnchanged,
    renderRevertControl
  };
  useImperativeHandle(ref, () => ({
    container: editor.current,
    view: view.current,
    modified,
    original,
    config: _extends({
      a: original,
      b: modified,
      parent: editor.current
    }, opts)
  }), [editor, view, modified, original, opts]);
  useEffect(() => {
    if (!view.current && editor.current) {
      view.current = new MergeView(_extends({
        a: _extends({}, original, {
          extensions: [...((originalExtension == null ? void 0 : originalExtension.extension) || []), ...getDefaultExtensions(_extends({}, originalExtension == null ? void 0 : originalExtension.option, {
            theme
          }))]
        }),
        b: _extends({}, modified, {
          extensions: [...((modifiedExtension == null ? void 0 : modifiedExtension.extension) || []), ...getDefaultExtensions(_extends({}, modifiedExtension == null ? void 0 : modifiedExtension.option, {
            theme
          }))]
        }),
        parent: editor.current
      }, opts));
    }
  }, [view, editor]);
  useEffect(() => {
    var _view$current5;
    if (original && original.doc && view.current) {
      var _view$current;
      var originalDoc = (_view$current = view.current) == null ? void 0 : _view$current.a.state.doc.toString();
      if (originalDoc !== original.doc) {
        var _view$current2;
        (_view$current2 = view.current) == null || _view$current2.a.dispatch({
          changes: {
            from: 0,
            to: originalDoc.length,
            insert: original.doc || ''
          }
          // effects: StateEffect.reconfigure.of([
          //   ...(originalExtension?.extension || []),
          //   ...getDefaultExtensions({ ...originalExtension?.option, theme }),
          // ])
        });
      }
    }

    if (modified && modified.doc && view.current) {
      var _view$current3;
      var modifiedDoc = (_view$current3 = view.current) == null ? void 0 : _view$current3.b.state.doc.toString();
      if (modifiedDoc !== modified.doc) {
        var _view$current4;
        (_view$current4 = view.current) == null || _view$current4.b.dispatch({
          changes: {
            from: 0,
            to: modifiedDoc.length,
            insert: modified.doc || ''
          }
          // effects: StateEffect.reconfigure.of([
          //   ...(modifiedExtension?.extension || []),
          //   ...getDefaultExtensions({ ...modifiedExtension?.option, theme }),
          // ])
        });
      }
    }

    (_view$current5 = view.current) == null || _view$current5.destroy();
    view.current = new MergeView(_extends({
      a: _extends({}, original, {
        extensions: [...((originalExtension == null ? void 0 : originalExtension.extension) || []), ...getDefaultExtensions(_extends({}, originalExtension == null ? void 0 : originalExtension.option, {
          theme
        }))]
      }),
      b: _extends({}, modified, {
        extensions: [...((modifiedExtension == null ? void 0 : modifiedExtension.extension) || []), ...getDefaultExtensions(_extends({}, modifiedExtension == null ? void 0 : modifiedExtension.option, {
          theme
        }))]
      }),
      parent: editor.current
    }, opts));
  }, [view, theme, editor.current, original, modified, originalExtension, modifiedExtension]);
  useEffect(() => () => view.current && view.current.destroy(), []);
  useEffect(() => {
    if (view.current) {
      var _opts = {};
      if (otherStore.orientation !== orientation) {
        _opts.orientation = orientation;
      }
      if (otherStore.revertControls !== revertControls) {
        _opts.revertControls = revertControls;
      }
      if (otherStore.highlightChanges !== highlightChanges) {
        _opts.highlightChanges = highlightChanges;
      }
      if (otherStore.gutter !== gutter) {
        _opts.gutter = gutter;
      }
      if (otherStore.collapseUnchanged !== collapseUnchanged) {
        _opts.collapseUnchanged = collapseUnchanged;
      }
      if (otherStore.renderRevertControl !== renderRevertControl) {
        _opts.collapseUnchanged = collapseUnchanged;
      }
      if (Object.keys(_opts).length && dispatch && view.current) {
        view.current.reconfigure(_extends({}, _opts));
        dispatch(_extends({}, _opts));
      }
    }
  }, [dispatch, view, orientation, revertControls, highlightChanges, gutter, collapseUnchanged, renderRevertControl]);
  var defaultClassNames = 'cm-merge-theme';
  return /*#__PURE__*/_jsx("div", _extends({
    ref: editor,
    className: "" + defaultClassNames + (className ? " " + className : '')
  }, elmProps, {
    children: children
  }));
});
Internal.displayName = 'CodeMirrorMerge.Internal';
